package hr.fer.tel.ruazosa.stopwatch;

import android.os.Bundle;
import android.os.IBinder;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.Button;
import android.widget.TextView;
import android.app.Activity;
import android.content.ComponentName;
import android.content.Context;
import android.content.Intent;
import android.content.ServiceConnection;

public class StopWatchActivity extends Activity {

	private StopWatchService serviceReference;

	// handles the connection between the service and activity
	private ServiceConnection serviceConnection = new ServiceConnection() {
		public void onServiceConnected(ComponentName className, IBinder service) {
			// called when the connection is made
			serviceReference = ((StopWatchService.SWSBinder) service)
					.getService();

			SimpleStopWatch stopWatch = serviceReference.getStopWatch();

			// set elapsed time as shown time
			StopWatchActivity.this.runOnUiThread(new UpdateShownTime(stopWatch
					.getElapsedTimeSec()));

			// set tick listener
			stopWatch.setTickListener(new SimpleStopWatch.OnTickListener() {
				@Override
				public void onTick(long elapsedTime) {
					// update view
					StopWatchActivity.this.runOnUiThread(new UpdateShownTime(
							elapsedTime));
				}
			});
		}

		public void onServiceDisconnected(ComponentName className) {
			// received when the service unexpectedly disconnects
			serviceReference = null;
		}
	};

	@Override
	public void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.activity_stop_watch);

		// stopwatch service is a started service
		Intent startIntent = new Intent(StopWatchActivity.this,
				StopWatchService.class);
		startService(startIntent);

		// stopwatch service is a bounded service
		Intent bindIntent = new Intent(StopWatchActivity.this,
				StopWatchService.class);
		bindService(bindIntent, serviceConnection, Context.BIND_AUTO_CREATE);

		// watch for button clicks
		Button button = (Button) findViewById(R.id.button_play);
		button.setOnClickListener(new OnClickListener() {
			public void onClick(View v) {
				serviceReference.getStopWatch().startIt();
			}
		});

		button = (Button) findViewById(R.id.button_pause);
		button.setOnClickListener(new OnClickListener() {
			public void onClick(View v) {
				serviceReference.getStopWatch().pauseIt();
			}
		});

		button = (Button) findViewById(R.id.button_stop);
		button.setOnClickListener(new OnClickListener() {
			public void onClick(View v) {
				serviceReference.getStopWatch().stopIt();
				serviceReference.getStopWatch().resetIt();

				// reset shown time
				UpdateShownTime updateTextView = new UpdateShownTime(0L);
				StopWatchActivity.this.runOnUiThread(updateTextView);
			}
		});
	}

	@Override
	protected void onDestroy() {
		super.onDestroy();

		// stop service if stopwatch is not running
		if (serviceReference != null
				&& !serviceReference.getStopWatch().isRunning()) {
			Intent stopIntent = new Intent(StopWatchActivity.this,
					StopWatchService.class);
			startService(stopIntent);
		}

		// explicitly unbind service
		this.unbindService(serviceConnection);
	}

	private class UpdateShownTime implements Runnable {

		private long elapsedTime;

		public UpdateShownTime(long elapsedTime) {
			super();
			this.elapsedTime = elapsedTime;
		}

		public void run() {
			TextView stopWatchTextview = (TextView) findViewById(R.id.textview_stopwatch);
			stopWatchTextview.setText(formatIntoHHMMSS(elapsedTime));
		}

		private String formatIntoHHMMSS(long secs) {

			long hours = secs / 3600, remainder = secs % 3600, minutes = remainder / 60, seconds = remainder % 60;

			return ((hours < 10 ? "0" : "") + hours + ":"
					+ (minutes < 10 ? "0" : "") + minutes + ":"
					+ (seconds < 10 ? "0" : "") + seconds);
		}
	}
}
